<?php

namespace Drupal\pardot;

/**
 * Provides an interface for defining Pardot Form Map entities.
 */
interface FormMapInterface {

  /**
   * Get the form handler post url.
   *
   * @return string
   *   The uri.
   */
  public function getPostUrl();

  /**
   * Set the form handler post uri.
   *
   * @param string $post_url
   *   The form handler uri.
   */
  public function setPostUrl(string $post_url);


  /**
   * Get the form handler id.
   *
   * @return int
   *   The id.
   */
  public function getFormHandlerId();

  /**
   * Set the form handler id.
   *
   * @param string $id
   *   The form handler id.
   */
  public function setFormHandlerId(string $id);

  /**
   * Get the array of MappedField instances.
   *
   * @return \Drupal\pardot\MappedField[]
   *   The array of MappedField instances.
   */
  public function getMappedFieldCollection();

  /**
   * Set the array of field map configurations.
   *
   * @param \Drupal\pardot\MappedField[] $mapping
   *   The array of MappedField instances.
   */
  public function setMappedFieldCollection(array $mapping);

}
