<?php

namespace Drupal\pardot;

/**
 * Provides a class for mapped fields.
 */
abstract class MappedFieldBase implements MappedFieldInterface {

  /**
   * Whether this field map is disabled due to not mapping anywhere in Pardot.
   *
   * @var bool
   */
  protected $status;

  /**
   * Whether this field map is disabled due to not mapping anywhere in Pardot.
   *
   * @var bool
   */
  protected $required;

  /**
   * The pardot field key to map the value to.
   *
   * @var string
   */
  protected $pardotKey;

  /**
   * The plguin Type.
   *
   * @var string
   */
  protected $pluginType;

  /**
   * The Plugin associated with this map.
   *
   * @var mixed
   */
  protected $plugin;

  /**
   * {@inheritdoc}
   */
  public function __construct(string $pardot_key = '', $plugin_type = '', $plugin = [], $config = [], $required = FALSE) {
    $this->pardotKey = $pardot_key;
    $this->pluginType = $plugin_type;
    $this->plugin = $plugin;
    $this->status = TRUE;
    $this->required = $required;
  }

  /**
   * {@inheritdoc}
   */
  public function getPardotKey() {
    return $this->pardotKey;
  }

  /**
   * {@inheritdoc}
   */
  public function setPardotKey($pardot_key) {
    $this->pardotKey = $pardot_key;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isRequired() {
    return $this->required;
  }

  /**
   * {@inheritdoc}
   */
  public function setIsRequired(bool $bool) {
    $this->required = $bool;
    return $this;
  }


  /**
   * {@inheritdoc}
   */
  public function getStatus() {
    return $this->status;
  }

  /**
   * {@inheritdoc}
   */
  public function setStatus(bool $bool) {
    $this->status = $bool;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginType() {
    return $this->pluginType;
  }

  /**
   * {@inheritdoc}
   */
  public function setPluginType(string $plugin_type) {
    $this->pluginType = $plugin_type;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPlugin() {
    return $this->plugin;
  }

  /**
   * {@inheritdoc}
   */
  public function setPlugin($plugin) {
    $this->plugin = $plugin;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function toArray() {
    return [
      'pardot_key' => $this->getPardotKey(),
      'plugin_type' => $this->getPluginType(),
      'plugin' => $this->getPlugin(),
      'status' => $this->getStatus(),
      'required' => $this->isRequired(),
      'class' => get_called_class(),
    ];
  }

}
