<?php

namespace Drupal\pardot\Routing;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Subscriber for Devel routes.
 *
 * @see \Drupal\devel\Controller\EntityDebugController
 * @see \Drupal\devel\Plugin\Derivative\DevelLocalTask
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityTypeManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($entity_type_id === 'contact_form' || $entity_type_id === 'webform') {
        if ($route = $this->getFormRoute($entity_type)) {
          $collection->add("entity.{$entity_type_id}.pardot_form_mapping", $route);
        }
      }
    }

    return $collection;
  }

  /**
   * Gets the version history route.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   *
   * @return \Symfony\Component\Routing\Route|null
   *   The generated route, if available.
   */
  protected function getFormRoute(EntityTypeInterface $entity_type) {
    if ($route = new Route($entity_type->getLinkTemplate('pardot-form-mapping'))) {
      $entity_type_id = $entity_type->id();

      if ($entity_type_id === 'contact_form') {
        $method = 'renderContactFormMapping';
      }
      if ($entity_type_id === 'webform') {
        $method = 'renderWebformFormMapping';
      }
      if ($method) {
        $route
          ->setDefaults([
  //          '_title' => "Pardot Form Map: @contact_form",
            '_title' => "Pardot Form Map",
            '_controller' => '\Drupal\pardot\Controller\PardotFormMappingController::' . $method,
          ])
          ->setRequirement('_permission', 'administer pardot form map')
          ->setOption('parameters', [
            $entity_type_id => 'entity:' . $entity_type_id,
          ])
          ->setOption('_admin_route', TRUE);

        return $route;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = parent::getSubscribedEvents();
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', 100];
    return $events;
  }

}
